#'
#' Functions Supporting Packages ChemoSpec and ChemoSpec2D
#'
#' Functions supporting the packages ChemoSpec and ChemoSpec2D.
#'
#' @name ChemoSpecUtils-package
#'
#' @aliases ChemoSpecUtils-package ChemoSpecUtils
#'
#'
#' @author `r .writeDoc_Authors(c("BH", "TG"))`
#'
#' Maintainer: Bryan A. Hanson \email{hanson@@depauw.edu}
#'
"_PACKAGE"
